==> camitk_3.4.0.orig.tar.gz: camitk-3.4.0-Source/modeling/libraries/mml/monitoring/Position.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef STOPPINGCRITERION_STOPPINGCRITERIA_CRITERIA_POSITION_H
#define STOPPINGCRITERION_STOPPINGCRITERIA_CRITERIA_POSITION_H

#include "MonitorIn.hxx"

// Stopping criteria includes
#include "Criterion.h"
/**
 *
 * @ingroup group_cepmodeling_libraries_mml
 *
 * @brief
 * A simple criterion based on position calculation
 */
class Position: public Criterion {
public:
    /**
    * constructor
    *@param c the xsdcxx generated Position criterion
    */
    Position(mml::Position* c,MonitoringManager* monitoringManager, MultipleCriterion* parent=NULL);
    /// destructor
    ~Position();

    /// get stopping criterion name
    std::string getName();

private:
    /// calculate stopping criteria data and store it into values vector
    void calculate();
};

#endif // STOPPINGCRITERION_STOPPINGCRITERIA_CRITERIA_POSITION_H

==> camitk_4.0.4.orig.tar.gz: camitk-4.0.4-Source/modeling/libraries/mml/monitoring/Position.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef STOPPINGCRITERION_STOPPINGCRITERIA_CRITERIA_POSITION_H
#define STOPPINGCRITERION_STOPPINGCRITERIA_CRITERIA_POSITION_H

#include <MonitorIn.hxx>

// Stopping criteria includes
#include "Criterion.h"
/**
 *
 * @ingroup group_cepmodeling_libraries_mml
 *
 * @brief
 * A simple criterion based on position calculation
 */
class Position: public Criterion {
public:
    /**
    * constructor
    *@param c the xsdcxx generated Position criterion
    */
    Position(mml::Position* c,MonitoringManager* monitoringManager, MultipleCriterion* parent=NULL);
    /// destructor
    ~Position();

    /// get stopping criterion name
    std::string getName();

private:
    /// calculate stopping criteria data and store it into values vector
    void calculate();
    
    /// the monitor targets describe as an LML TargetList string (e.g. "1-4,5"), @see TargetList
    std::string target;
};

#endif // STOPPINGCRITERION_STOPPINGCRITERIA_CRITERIA_POSITION_H
